"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jwt = require("jsonwebtoken");
const Auth_1 = require("../Auth");
class AuthService {
    constructor(options) {
        this.publicKeys = options.publicKeys || new Map();
    }
    registerPublicKey(keyId, publicKeyPem) {
        this.publicKeys.set(keyId, publicKeyPem);
    }
    removePublicKey(keyId) {
        this.publicKeys.delete(keyId);
    }
    /**
     * Validates a signed Auth
     * @param {string} signed the signed auth to validate
     */
    validate(signed) {
        const headerEncoded = signed.substr(0, signed.indexOf('.'));
        const headerStr = Buffer.from(headerEncoded, 'base64').toString();
        const header = JSON.parse(headerStr);
        if (!header.keyid) {
            throw new Error('The JWT doesn\'t contain a key id. Can\'t validate');
        }
        const keyId = header.keyid;
        if (!this.publicKeys.has(keyId)) {
            throw new Error(`Unknown key id ${keyId}. Token is not valid`);
        }
        const publicKey = this.publicKeys.get(keyId);
        const verified = jwt.verify(signed, publicKey);
        return new Auth_1.Auth(verified.subT, verified.sub, verified.roles, verified.extraRoles);
    }
}
exports.AuthService = AuthService;
//# sourceMappingURL=AuthService.js.map