"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jwt = require("jsonwebtoken");
const Auth_1 = require("../Auth");
const AuthService_1 = require("./AuthService");
class SigningAuthService extends AuthService_1.AuthService {
    constructor(options) {
        super(options);
        options = options || {};
        if (!options.issuer) {
            throw new Error('Please specify an issuer in the options');
        }
        if (!options.privateKeyId) {
            throw new Error('Please specify a privateKeyId in the options');
        }
        if (!options.privateKeyPem) {
            throw new Error('Please specify a privateKeyPem in the options');
        }
        this.privateKeyPem = options.privateKeyPem;
        this.tokenOptions = Object.assign({ algorithm: 'RS512', expiresIn: '30d', header: {} }, (options.tokenOptions || {}));
        this.tokenOptions.issuer = options.issuer;
        this.tokenOptions.header['keyid'] = options.privateKeyId;
    }
    /**
     * Signs an Auth object
     * @param {Auth} auth The authorisation to convert into a signed token
     */
    sign(auth) {
        if (!(auth instanceof Auth_1.Auth)) {
            throw new Error('Provided input to sign is not an Auth');
        }
        const payload = {
            sub: auth.getId(),
            subT: auth.getType(),
            roles: auth.getRoles(),
            extraRoles: auth.getExtraRoles(),
        };
        return jwt.sign(payload, this.privateKeyPem, this.tokenOptions);
    }
}
exports.SigningAuthService = SigningAuthService;
//# sourceMappingURL=SigningAuthService.js.map