/// <reference types="node" />
import { Stream } from 'stream';
import { SingletonDefinition } from 'inceptum';
import { AggregateEventStore } from './event/store/AggregateEventStore';
import { ExecutionContext } from './ExecutionContext';
import { Aggregate } from './Aggregate';
import { Command } from './command/Command';
import { CommandExecutor } from './command/CommandExecutor';
import { EventExecutor } from './event/EventExecutor';
export declare abstract class EventListener {
    abstract eventCommitted(event: any): any;
}
export declare class CQRS {
    aggregateEventStore: AggregateEventStore;
    commandClasses: Map<string, Function>;
    aggregateClasses: Map<string, Function>;
    aggregateCache: any;
    eventStream: Stream;
    commandExecutors: CommandExecutor<any, any>[];
    eventExecutors: EventExecutor<any, any>[];
    aggregateDefinitionsToRegister: SingletonDefinition<any>[];
    commandDefinitionsToRegister: SingletonDefinition<any>[];
    eventListeners: EventListener[];
    private doSetup();
    /**
     * Construct a new instance of the CQRS framework
     * @param {AggregateEventStore} aggregateEventStore The event store to use.
     */
    constructor(aggregateEventStore: AggregateEventStore);
    newExecutionContext(): ExecutionContext;
    getEventStream(): Stream;
    /**
     * Executes a single command and return the ExecutionContext
     * @param {Command[]} commands The command to execute
     * @returns {ExecutionContext} The execution context of the command
     */
    executeCommand(...commands: Command[]): Promise<ExecutionContext>;
    getAggregateAs<T extends Aggregate>(aggregateId: string): Promise<T>;
    getAggregate(aggregateId: string): Promise<Aggregate>;
    private getAggregateInternal(aggregateId);
    deserialiseCommand<T extends Command>(obj: any, commandType: any): T;
    registerAggregateClass(name: string, aggregateClass: Function): void;
    registerCommandClass(name: string, commandClass: Function): void;
    private instantiateAggregate(aggregateType, aggregateId);
    registerCommandExecutor<T extends Command, A extends Aggregate>(commandExecutor: CommandExecutor<T, A>): void;
    registerEventExecutor<E, A extends Aggregate>(eventExecutor: EventExecutor<E, A>): void;
}
