import { CommandExecutor } from './command/CommandExecutor';
import { Aggregate } from './Aggregate';
import { AggregateCommand } from './command/AggregateCommand';
import { AggregateEventStore } from './event/store/AggregateEventStore';
import { CommandResult } from './command/CommandResult';
import { EventExecutor } from './event/EventExecutor';
export declare enum Status {
    NOT_COMMMITED = 0,
    COMMITTING = 1,
    COMMITTED = 2,
}
export declare class ExecutionContext extends AggregateEventStore {
    eventExecutors: EventExecutor<any, any>[];
    commandExecutors: CommandExecutor<any, any>[];
    commandResults: Map<string, CommandResult>;
    error: Error;
    commandsToExecute: AggregateCommand[];
    eventsToEmit: Object[];
    status: Status;
    aggregateEventStore: AggregateEventStore;
    aggregateClasses: Map<string, Function>;
    /**
     * Constructs a new instance of ExecutionContext
     * @param {AggregateEventStore} aggregateEventStore The store to commit events to
     */
    constructor(aggregateEventStore: AggregateEventStore, commandExecutors: CommandExecutor<any, any>[], eventExecutors: EventExecutor<any, any>[]);
    /**
     * Saves an aggregate event to this execution context.
     * The events won't be really saved on the aggregateEventStore until all
     * commands have been executed and the execution has been successful.
     * @param {aggregateEvent} aggregateEvent The aggregate event to store
     */
    commitEvent(event: any): Promise<void>;
    /**
     * Adds a command to the queue of commands to be executed.
     * @param {AggregateCommand} aggregateCommand The command to add to the execution queue
     */
    addCommandToExecute(aggregateCommand: AggregateCommand): void;
    /**
     * Validates that this execution context has not been committed yet.
     * @private
     */
    validateNotCommitted(): void;
    getAggregate(aggregateId: any): Promise<Aggregate>;
    /**
     * Get all uncommitted events for the given aggregate id
     * @private
     * @param {string} aggregateId The id of the aggregate
     */
    getUncommittedEventsOf(aggregateId: any): Object[];
    /**
     * Executes a single command. This is a convenience method that calls both {@link addCommandToExecute} and
     * {@link commit}
     * @param {AggregateCommand} command The command to execute
     */
    executeCommand(...commands: any[]): Promise<void>;
    /**
     * Commits the execution context.
     * This essentially will go through all commands pending execution and will call them in order. It will
     * fail on the first error that gets thrown by any of the commands, and this won't be able to be committed.
     */
    commit(): Promise<void>;
    getError(): Error;
    hasCommandResultForCommand(command: any): boolean;
    getCommandResultForCommand(command: any): CommandResult;
    getEventsOf(aggregateId: string): Promise<Array<any>>;
    setAggregateClasses(aggregateClasses: Map<string, Function>): void;
}
