import { Auth } from '../../auth/Auth';
import { IdGenerator } from '../IdGenerator';
export declare type CommandOptions = {
    issuerAuth?: Auth;
    commandId?: string;
    commandTimestamp?: number;
};
export declare abstract class Command {
    static commandFieldType: string;
    issuerAuth: Auth;
    commandId: string;
    commandTimestamp: number;
    /**
     * Creates a new command instance from the provided info.
     * @param {object} obj The object to take parameters from
     * @param {Auth} issuerAuth The Auth object of the issuer of this command
     * @param {[string]} commandId The id for this command. If not specified, the IdGenerator will be called to generate one
     */
    constructor(obj: CommandOptions);
    getCommandId(): string;
    getCommandType(): string;
    /**
     * The unix timestamp (milliseconds since Epoch) when this command was issued
     */
    getCommandTimestamp(): number;
    getIssuerAuth(): Auth;
    protected getIdGenerator(): IdGenerator;
}
