"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const IdGenerator_1 = require("../IdGenerator");
const defaultGenerator = new IdGenerator_1.UUIDGenerator();
class Command {
    /**
     * Creates a new command instance from the provided info.
     * @param {object} obj The object to take parameters from
     * @param {Auth} issuerAuth The Auth object of the issuer of this command
     * @param {[string]} commandId The id for this command. If not specified, the IdGenerator will be called to generate one
     */
    constructor(obj) {
        this.issuerAuth = obj.issuerAuth;
        this.commandTimestamp = obj.commandTimestamp || new Date().getTime();
        this.commandId = obj.commandId || this.getIdGenerator().generate(this.constructor.name);
        this[Command.commandFieldType] = this.constructor.name;
    }
    getCommandId() {
        return this.commandId;
    }
    getCommandType() {
        return this[Command.commandFieldType];
    }
    /**
     * The unix timestamp (milliseconds since Epoch) when this command was issued
     */
    getCommandTimestamp() {
        return this.commandTimestamp;
    }
    getIssuerAuth() {
        return this.issuerAuth;
    }
    // tslint:disable-next-line:prefer-function-over-method
    getIdGenerator() {
        return defaultGenerator;
    }
}
Command.commandFieldType = '@commandType';
exports.Command = Command;
//# sourceMappingURL=Command.js.map