"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const prom_client_1 = require("prom-client");
const ReturnToCallerError_1 = require("../error/ReturnToCallerError");
const AggregateCreatingCommand_1 = require("./AggregateCreatingCommand");
const AggregateCommand_1 = require("./AggregateCommand");
const commandTimer = new prom_client_1.Histogram({
    name: 'cqrs_command_timer',
    help: 'Timer for the command histogram',
    labelNames: ['command'],
    buckets: [0.001, 0.005, 0.01, 0.05, 0.1, 0.3, 0.5, 1],
});
const commandErrorCounter = new prom_client_1.Counter({
    name: 'cqrs_command_error_counter',
    labelNames: ['command', 'errorType'],
    help: 'Number of commands that have an error',
});
class CommandExecutor {
    /**
     * Executed this command as part of the execution context.
     * @param {T} command
     * @param {ExecutionContext} executionContext
     * @param {A} aggregate? If the command is an instance of AggregateCommand an aggregate should be present
     * @returns {*}
     */
    execute(command, executionContext, aggregate) {
        return __awaiter(this, void 0, void 0, function* () {
            const timer = commandTimer.startTimer({ command: command ? command.getCommandType() : 'na' });
            try {
                if (command instanceof AggregateCommand_1.AggregateCommand && (!aggregate && !(command instanceof AggregateCreatingCommand_1.AggregateCreatingCommand))) {
                    throw new ReturnToCallerError_1.ReturnToCallerError(`Execution of an AggregateCommand of type ${command.constructor.name} must have a valid aggregate`);
                }
                yield this.validate(command, executionContext, aggregate);
                yield this.validateAuth(command, executionContext, aggregate);
                yield this.doExecute(command, executionContext, aggregate);
            }
            catch (e) {
                commandErrorCounter.labels(command ? command.getCommandType() : 'na', e && e.contructor && e.constructor.name ? e.constructor.name : 'na').inc();
                throw e;
            }
            finally {
                timer();
            }
        });
    }
}
exports.CommandExecutor = CommandExecutor;
//# sourceMappingURL=CommandExecutor.js.map