"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inceptum_1 = require("inceptum");
class ReturnToCallerError extends inceptum_1.ExtendedError {
    constructor(message, httpStatusCode = 500, cause) {
        super(message, cause);
        this.httpStatusCode = httpStatusCode;
        this.name = 'ReturnToCallerError';
    }
    /**
     * Do not override this method. This is the method you should call to know what to return to the caller
     */
    getAllInfoToReturn() {
        if (this.causingError) {
            const toReturn = this.getInfoToReturn();
            if (this.causingError instanceof ReturnToCallerError) {
                toReturn['cause'] = this.causingError.getAllInfoToReturn();
            }
            else {
                toReturn['cause'] = { message: this.causingError.message };
            }
            return toReturn;
        }
        return this.getInfoToReturn();
    }
    /**
     * Please override this method to return whatever information you want to give back to the caller
     */
    getInfoToReturn() {
        return { message: this.message };
    }
}
exports.ReturnToCallerError = ReturnToCallerError;
//# sourceMappingURL=ReturnToCallerError.js.map