"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const EventExecutor_1 = require("../EventExecutor");
const AggregateEventStore_1 = require("./AggregateEventStore");
class InMemoryAggregateEventStore extends AggregateEventStore_1.AggregateEventStore {
    constructor(eventExecutors) {
        super();
        this.eventExecutors = [];
        this.store = new Map();
        this.eventExecutors = eventExecutors;
    }
    /**
     * Load all the events of an aggregate
     * @param {string} aggregateId The id of the aggregate whose events we want to load
     * @returns {AggregateEvent[]} The list of aggregate events of this aggregate
     */
    // eslint-disable-next-line no-unused-vars
    getEventsOf(aggregateId) {
        return __awaiter(this, void 0, void 0, function* () {
            const eventStrArr = this.store.get(aggregateId);
            if (!eventStrArr || eventStrArr.length === 0) {
                return [];
            }
            return eventStrArr;
        });
    }
    /**
     * Saves an aggregate event to the persistent store
     * @param {AggregateEvent} aggregateEvent The aggregate event to store
     */
    // eslint-disable-next-line no-unused-vars
    commitEvent(aggregateEvent) {
        return __awaiter(this, void 0, void 0, function* () {
            const executor = EventExecutor_1.EventExecutor.getEventExecutor(aggregateEvent, this.eventExecutors);
            if (!executor) {
                throw new Error(`Unknown event to commit ${aggregateEvent.constructor.name}`);
            }
            const aggregateId = executor.getAggregateId(aggregateEvent);
            if (!this.store.has(aggregateId)) {
                const events = [];
                events.push(aggregateEvent);
                this.store.set(aggregateId, events);
            }
            else {
                const events = this.store.get(aggregateId);
                events.push(aggregateEvent);
            }
        });
    }
}
exports.InMemoryAggregateEventStore = InMemoryAggregateEventStore;
//# sourceMappingURL=InMemoryAggregateEventStore.js.map