"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inceptum_1 = require("inceptum");
const CQRS_1 = require("../CQRS");
const ReturnToCallerError_1 = require("../error/ReturnToCallerError");
const SwaggerCQRSMiddleware_1 = require("./SwaggerCQRSMiddleware");
const logger = inceptum_1.LogManager.getLogger(__filename);
const newrelic = inceptum_1.NewrelicUtil.getNewrelicIfAvailable();
let WireCQRSPlugin = class WireCQRSPlugin {
    wire() {
        this.middleware.setCQRS(this.cqrs);
    }
};
__decorate([
    inceptum_1.Autowire('CQRS')
], WireCQRSPlugin.prototype, "cqrs", void 0);
__decorate([
    inceptum_1.StartMethod
], WireCQRSPlugin.prototype, "wire", null);
WireCQRSPlugin = __decorate([
    inceptum_1.Lazy(false)
], WireCQRSPlugin);
exports.WireCQRSPlugin = WireCQRSPlugin;
class CQRSPlugin {
    constructor(cqrsDefinitionConfigurator) {
        this.name = 'CQRSPlugin';
        this.configurator = cqrsDefinitionConfigurator;
    }
    // tslint:disable-next-line:prefer-function-over-method
    willStart(app, pluginContext) {
        return __awaiter(this, void 0, void 0, function* () {
            logger.info('Registering CQRS support');
            const context = app.getContext();
            const singletonDefinition = new inceptum_1.BaseSingletonDefinition(CQRS_1.CQRS);
            context.registerDefinition(singletonDefinition);
            if (this.configurator) {
                this.configurator(singletonDefinition);
            }
            const express = pluginContext.get(inceptum_1.WebPlugin.CONTEXT_APP_KEY);
            if (express) {
                const middleware = new SwaggerCQRSMiddleware_1.SwaggerCQRSMiddleware();
                middleware.register(express);
                const wireDefinition = new inceptum_1.BaseSingletonDefinition(WireCQRSPlugin);
                // wireDefinition.withLazyLoading(false);
                wireDefinition.setPropertyByValue('middleware', middleware);
                // wireDefinition.setPropertyByRef('cqrs', 'CQRS');
                // wireDefinition.startFunction('wire');
                context.registerDefinition(wireDefinition);
            }
        });
    }
    didStart(app, pluginContext) {
        return __awaiter(this, void 0, void 0, function* () {
            const express = pluginContext.get(inceptum_1.WebPlugin.CONTEXT_APP_KEY);
            if (express) {
                express.use((err, req, res, next) => {
                    if (newrelic) {
                        newrelic.noticeError(err);
                    }
                    if (err instanceof ReturnToCallerError_1.ReturnToCallerError) {
                        res.status(err.httpStatusCode).send(err.getAllInfoToReturn());
                    }
                    else if (req.swagger) {
                        res.status(500).send({ message: 'Internal Server Error' });
                    }
                    else {
                        next(err);
                    }
                });
            }
        });
    }
}
exports.CQRSPlugin = CQRSPlugin;
//# sourceMappingURL=CQRSPlugin.js.map